==> react-jsonschema-form-ui2-1.0.2.tgz: package/es/widgets/CurrencyWidget.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from "react";
import { accounting } from "accounting";

var CurrencyWidget = /*#__PURE__*/function (_Component) {
  _inheritsLoose(CurrencyWidget, _Component);

  function CurrencyWidget(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.precision = props.options.precision === undefined ? 2 : props.options.precision;
    accounting.settings = {
      currency: {
        symbol: !props.options.symbol ? "$" : props.options.symbol,
        // default currency symbol is '$'
        format: !props.options.format ? "%s%v" : props.options.format,
        // controls output: %s = symbol, %v = value/number
        decimal: ".",
        // decimal point separator
        thousand: ",",
        // thousands separator
        precision: _this.precision // decimal places

      },
      number: {
        precision: _this.precision,
        // default precision on numbers is 0
        thousand: ",",
        decimal: "."
      }
    };
    _this.state = _extends({}, props, {
      precision: _this.precision,
      value: accounting.formatMoney(props.value / 100)
    });
    return _this;
  }

  var _proto = CurrencyWidget.prototype;

  _proto.render = function render() {
    var _this2 = this;

    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("input", {
      type: "text",
      className: "form-control currency",
      style: {
        textAlign: "right"
      },
      value: this.state.value,
      required: this.state.required,
      onBlur: function onBlur(event) {
        _this2.state.onChange((accounting.unformat(event.target.value) * 100).toFixed(_this2.precision));

        _this2.setState({
          value: accounting.formatMoney(event.target.value)
        });
      },
      onChange: function onChange(event) {
        _this2.setState({
          value: event.target.value
        }, function () {
          return _this2.state.onChange(accounting.unformat(_this2.state.value).toFixed(_this2.precision) * 100);
        });
      },
      disabled: this.state.disabled,
      readOnly: this.state.readonly
    }));
  };

  return CurrencyWidget;
}(Component);

export default CurrencyWidget;

==> react-jsonschema-form-ui2-2.0.1.tgz: package/es/widgets/CurrencyWidget.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from "react";
import { Form } from "react-bootstrap";
import { accounting } from "accounting";

var CurrencyWidget = /*#__PURE__*/function (_Component) {
  _inheritsLoose(CurrencyWidget, _Component);

  function CurrencyWidget(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.precision = props.options.precision === undefined ? 2 : props.options.precision;
    accounting.settings = {
      currency: {
        symbol: !props.options.symbol ? "$" : props.options.symbol,
        // default currency symbol is '$'
        format: !props.options.format ? "%s%v" : props.options.format,
        // controls output: %s = symbol, %v = value/number
        decimal: ".",
        // decimal point separator
        thousand: ",",
        // thousands separator
        precision: _this.precision // decimal places

      },
      number: {
        precision: _this.precision,
        // default precision on numbers is 0
        thousand: ",",
        decimal: "."
      }
    };
    _this.state = _extends({}, props, {
      precision: _this.precision,
      value: accounting.formatMoney(props.value / 100)
    });
    return _this;
  }

  var _proto = CurrencyWidget.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _$get = _.get(this.props, "schema", {}),
        title = _$get.title;

    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Form.Label, null, title), /*#__PURE__*/React.createElement("input", {
      type: "text",
      className: "form-control currency",
      style: {
        textAlign: "right"
      },
      value: this.state.value,
      required: this.state.required,
      onBlur: function onBlur(event) {
        _this2.state.onChange((accounting.unformat(event.target.value) * 100).toFixed(_this2.precision));

        _this2.setState({
          value: accounting.formatMoney(event.target.value)
        });
      },
      onChange: function onChange(event) {
        _this2.setState({
          value: event.target.value
        }, function () {
          return _this2.state.onChange(accounting.unformat(_this2.state.value).toFixed(_this2.precision) * 100);
        });
      },
      disabled: this.state.disabled,
      readOnly: this.state.readonly
    }));
  };

  return CurrencyWidget;
}(Component);

export default CurrencyWidget;
